Class: Rails::Hyperdrive::GemManifest::TargetSpec

Inherits:
Struct
  • Object
show all
Defined in:
lib/rails/hyperdrive/gem_manifest.rb

Overview

warning, when set, is phrased for the caller to prefix with its own context — the parser has no idea which entry it is reading.

Instance Attribute Summary collapse

Instance Attribute Details

#match_modeObject

Returns the value of attribute match_mode

Returns:

  • (Object)

    the current value of match_mode



30
31
32
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30

def match_mode
  @match_mode
end

#targetsObject

Returns the value of attribute targets

Returns:

  • (Object)

    the current value of targets



30
31
32
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30

def targets
  @targets
end

#versionsObject

Returns the value of attribute versions

Returns:

  • (Object)

    the current value of versions



30
31
32
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30

def versions
  @versions
end

#warningObject

Returns the value of attribute warning

Returns:

  • (Object)

    the current value of warning



30
31
32
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30

def warning
  @warning
end