Class: Rails::Hyperdrive::GemManifest::TargetSpec
- Inherits:
-
Struct
- Object
- Struct
- Rails::Hyperdrive::GemManifest::TargetSpec
- Defined in:
- lib/rails/hyperdrive/gem_manifest.rb
Overview
warning, when set, is phrased for the caller to prefix with its own
context — the parser has no idea which entry it is reading.
Instance Attribute Summary collapse
-
#match_mode ⇒ Object
Returns the value of attribute match_mode.
-
#targets ⇒ Object
Returns the value of attribute targets.
-
#versions ⇒ Object
Returns the value of attribute versions.
-
#warning ⇒ Object
Returns the value of attribute warning.
Instance Attribute Details
#match_mode ⇒ Object
Returns the value of attribute match_mode
30 31 32 |
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30 def match_mode @match_mode end |
#targets ⇒ Object
Returns the value of attribute targets
30 31 32 |
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30 def targets @targets end |
#versions ⇒ Object
Returns the value of attribute versions
30 31 32 |
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30 def versions @versions end |
#warning ⇒ Object
Returns the value of attribute warning
30 31 32 |
# File 'lib/rails/hyperdrive/gem_manifest.rb', line 30 def warning @warning end |